---
name: Bug Report
about: Create a bug report to help us fix a demonstrable problem with code in the library.
title: ''
labels: bug
assignees: 
---

### Describe the bug
A bug is _a demonstrable problem_ caused by code in the library. Please provide a clear and concise description of what the bug is here.

### To Reproduce
Steps to reproduce the behavior:

1. Go to '...'
2. Click on '...'
3. Scroll down to '...'
4. See error

### Demo

If the bug isn't obvious, please provide a link to a CodePen or Fiddle with a minimal reproduction. Bugs that have repros get attention faster than those that don't.

Tip: use the CodePen button on any example in the docs!

### Screenshots
If applicable, add screenshots to help explain the bug.

### Browser / OS
 - OS: [e.g. Mac, Windows]
 - Browser: [e.g. Chrome, Firefox, Safari]
 - Browser version: [e.g. 22]

### Additional information
Provide any additional information about the bug here.
